@@ -5,5 +5,9 @@
     improper_ctypes
 )]
 
+// Ensure that linker flags from link-cplusplus are used.
+extern crate link_cplusplus;
+
+
 // The name of this file comes from `build.rs`.
-include!(concat!("../", env!("CRATE_WSTP_SYS_BINDINGS")));
+include!(env!("CRATE_WSTP_SYS_BINDINGS"));
